California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Choose an Election Cycle: 2025 through 2026 Historical
HERE ARE YOUR RESULTS: Election Dates (Dates appear according to the Election Cycle above) 2025 - 2026 Election Dates: 1. SPECIAL ELECTION Tuesday, 2/25/25 2. SPECIAL ELECTION Tuesday, 2/25/25 3. SPECIAL ELECTION RUNOFF Tuesday, 4/29/25 4. SPECIAL ELECTION RUNOFF Tuesday, 4/29/25 5. SPECIAL ELECTION Tuesday, 6/24/25 6. SPECIAL ELECTION RUNOFF Tuesday, 8/26/25 7. SPECIAL ELECTION Monday, 9/29/25 8. SPECIAL ELECTION RUNOFF Monday, 12/8/25 9. PRIMARY ELECTION Tuesday, 6/2/26 10. GENERAL ELECTION Tuesday, 11/3/26
If you are searching for campaign finance information related to a specific office this is the place to begin. Included are officeholders for Governor, Lieutenant Governor, Secretary of State, Attorney General, State Controller, State Treasurer, Insurance Commissioner, State Superintendent of Public Instruction, Board of Equalization, State Senate, and State Assembly. Here you will find their names, campaign committees, and other information.
SENATE DISTRICTS
STATE SENATE 01
DAHLE, MEGAN
| STATE SENATE 03
CABALDON, CHRISTOPHER
STATE SENATE 05
MC NERNEY, JERRY M.
| STATE SENATE 07
ARREGUIN, JESSE
STATE SENATE 09
GRAYSON, TIM
| STATE SENATE 11
WIENER, SCOTT D.
STATE SENATE 13
BECKER, JOSH
| STATE SENATE 15
CORTESE, DAVE
STATE SENATE 17
LAIRD, JOHN S.
| STATE SENATE 19
OCHOA BOGH, ROSILICIE
STATE SENATE 21
LIMON, S. MONIQUE
| STATE SENATE 23
MARTINEZ VALLADARES, SUZETTE
STATE SENATE 25
PEREZ, SASHA RENEE
| STATE SENATE 27
STERN, HENRY
STATE SENATE 29
REYES, ELOISE GOMEZ
| STATE SENATE 31
CERVANTES, SABRINA
STATE SENATE 33
GONZALEZ, LENA
| STATE SENATE 35
RICHARDSON, LAURA
STATE SENATE 36
STRICKLAND, TONY
| STATE SENATE 37
CHOI, STEVEN
STATE SENATE 39
WEBER, AKILAH
ASSEMBLY DISTRICTS
ASSEMBLY 01
HADWICK, HEATHER M.
| ASSEMBLY 02
ROGERS, CHRIS
ASSEMBLY 03
GALLAGHER, JAMES
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA
ASSEMBLY 05
PATTERSON, JOE
| ASSEMBLY 06
KRELL, MAGGY
ASSEMBLY 07
HOOVER, JOSH
| ASSEMBLY 08
TANGIPA, DAVID
ASSEMBLY 09
FLORA, HEATH
| ASSEMBLY 10
NGUYEN, STEPHANIE
ASSEMBLY 11
WILSON, LORI
| ASSEMBLY 12
CONNOLLY, DAMON
ASSEMBLY 13
RANSOM, RHODESIA
| ASSEMBLY 14
WICKS, BUFFY
ASSEMBLY 15
AVILA FARIAS, ANAMARIE
| ASSEMBLY 16
BAUER-KAHAN, REBECCA
ASSEMBLY 17
HANEY, MATT
| ASSEMBLY 18
BONTA, MIA
ASSEMBLY 19
STEFANI, CATHERINE
| ASSEMBLY 20
ORTEGA-TORO, LIZ
ASSEMBLY 21
PAPAN, DIANE
| ASSEMBLY 22
ALANIS, JUAN
ASSEMBLY 23
BERMAN, MARC E.
| ASSEMBLY 24
LEE, ALEX
ASSEMBLY 25
KALRA, ASH
| ASSEMBLY 26
AHRENS, PATRICK
ASSEMBLY 27
SORIA, ESMERALDA
| ASSEMBLY 28
PELLERIN, GAIL
ASSEMBLY 29
RIVAS, ROBERT
| ASSEMBLY 30
ADDIS, DAWN J.
ASSEMBLY 31
ARAMBULA, JOAQUIN
| ASSEMBLY 32
ELLIS, STAN
ASSEMBLY 33
MACEDO, ALEXANDRA M
| ASSEMBLY 34
LACKEY, THOMAS W.
ASSEMBLY 35
BAINS, JASMEET
| ASSEMBLY 36
GONZALEZ, JEFFREY
ASSEMBLY 37
HART, GREGG A.
| ASSEMBLY 38
BENNETT, STEPHEN A.
ASSEMBLY 39
CARRILLO, JUAN
| ASSEMBLY 40
SCHIAVO, PILAR
ASSEMBLY 41
HARABEDIAN, JOHN
| ASSEMBLY 42
IRWIN, JACQUI V.
ASSEMBLY 43
RODRIGUEZ, CELESTE
| ASSEMBLY 44
SCHULTZ, NICHOLAS BERNARD COOLON
ASSEMBLY 45
RAMOS, JAMES
| ASSEMBLY 46
GABRIEL, JESSE
ASSEMBLY 47
WALLIS, GREG
| ASSEMBLY 48
RUBIO, BLANCA
ASSEMBLY 49
FONG, MICHAEL
| ASSEMBLY 50
GARCIA, ROBERT
ASSEMBLY 51
ZBUR, RICK CHAVEZ
| ASSEMBLY 52
CALOZA, JESSICA
ASSEMBLY 53
RODRIGUEZ, MICHELLE
| ASSEMBLY 54
GONZALEZ, MARK
ASSEMBLY 55
BRYAN, ISAAC
| ASSEMBLY 56
CALDERON, LISA
ASSEMBLY 57
ELHAWARY, ZEINAB SADE
| ASSEMBLY 58
CASTILLO, LETICIA
ASSEMBLY 59
CHEN, PHILLIP
| ASSEMBLY 60
JACKSON, COREY A.
ASSEMBLY 61
MC KINNOR, TINA
| ASSEMBLY 62
SOLACHE, JOSE
ASSEMBLY 63
ESSAYLI, BILL
| ASSEMBLY 64
PACHECO, BLANCA
ASSEMBLY 65
GIPSON, MIKE
| ASSEMBLY 66
MURATSUCHI, AL
ASSEMBLY 67
QUIRK-SILVA, SHARON
| ASSEMBLY 68
VALENCIA, AVELINO
ASSEMBLY 69
LOWENTHAL, JOSH
| ASSEMBLY 70
TA, TRI
ASSEMBLY 71
SANCHEZ, KATHRYN
| ASSEMBLY 72
DIXON, DIANE
ASSEMBLY 73
PETRIE-NORRIS, COTTIE
| ASSEMBLY 74
DAVIES, LAURIE
ASSEMBLY 75
DE MAIO, CARL
| ASSEMBLY 76
PATEL, DARSHANA R
ASSEMBLY 77
BOERNER HORVATH, TASHA
| ASSEMBLY 78
WARD, CHRISTOPHER M.
ASSEMBLY 79
SHARP-COLLINS, LA SHAE N
| ASSEMBLY 80
ALVAREZ, DAVID